@@ -11,6 +11,15 @@ extern "C"
 {
 #endif
 
+// define if debug printf is needed
+//#define EC_DEBUG
+
+#ifdef EC_DEBUG
+#define EC_PRINT printf
+#else
+#define EC_PRINT(...) do {} while (0)
+#endif
+
 #ifndef PACKED
 #define PACKED_BEGIN __pragma(pack(push, 1))
 #define PACKED
